Learn R Programming

LotkasLaw (version 0.0.1.0)

CV: Runs Critical Value

Description

Runs Critical Value for Desired Data (in this case Sums). Assumes 1.63 Value.

Usage

CV(Sums)

Arguments

Sums
A Sumed Table of the Data Being Run Through Lotkas Law.

Value

The Value Returned is the Critical Value From the Data Inputted (as Sums)

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (Sums) 
{
    bottom <- sqrt(Sums[2])
    top <- 1.63
    answer <- top/bottom
    return(answer)
  }

Run the code above in your browser using DataLab