Learn R Programming

LotkasLaw (version 0.0.1.0)

CVm: Runs Critical Value based on custom value

Description

Runs Critical Value Based on Custom value.

Usage

CVm(value, Sums)

Arguments

value
Value Is the desired Critical Value test, See Refernces to determine the Values Needed.
Sums
A sumorization of The Data Being Tested.

Value

The value is the Critical Value Derived from Custom Critival Value Test.

References

The custom value inputed for Critical value can be found at both http://www.soest.hawaii.edu/wessel/courses/gg313/Critical_KS.pdf & also http://www.mathematik.uni-kl.de/~schwaar/Exercises/Tabellen/table_kolmogorov.pdf

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (value, Sums) 
{
    bottom <- sqrt(Sums[2])
    top <- value
    answer <- top/bottom
    return(answer)
  }

Run the code above in your browser using DataLab