Learn R Programming

LotkasLaw (version 0.0.1.0)

LotkasLogY: Generates a Table of Log base 10 of Y

Description

This forumla is to create the Log base 10 of Y

Usage

LotkasLogY(Table)

Arguments

Table
Table imported containing Papers and Authors.

Value

Returned value is a Column containing Log base 10 of Y

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (Table) 
{
    value <- log(Table[, 2:2], base = 10)
    return(value)
  }

Run the code above in your browser using DataLab