Learn R Programming

LotkasLaw (version 0.0.1.0)

percauthors: Runs a Percent of Authors Total from the table.

Description

Creates a Percent Authors Table based on each column variable for authors against the total.

Usage

percauthors(Table, Sums)

Arguments

Table
The Table of data that is being tested,
Sums
The sum of data based off the Table,

Value

The value returned is a table with percent Authors Table.

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (Table, Sums) 
{
    justy <- Table[, 2:2]
    newcol <- justy/Sums[2]
    return(newcol)
  }

Run the code above in your browser using DataLab